@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2008-2012
+Copyright (c) 2008-2013
 	Lars-Dominik Braun <lars@6xq.net>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -40,7 +40,7 @@ THE SOFTWARE.
  *	@param piano handle
  *	@return nothing
  */
-void PianoInit (PianoHandle_t *ph, const char *partnerUser,
+PianoReturn_t PianoInit (PianoHandle_t *ph, const char *partnerUser,
 		const char *partnerPassword, const char *device, const char *inkey,
 		const char *outkey) {
 	memset (ph, 0, sizeof (*ph));
@@ -48,15 +48,25 @@ void PianoInit (PianoHandle_t *ph, const char *partnerUser,
 	ph->partner.password = strdup (partnerPassword);
 	ph->partner.device = strdup (device);
 
-	gcry_cipher_open (&ph->partner.in, GCRY_CIPHER_BLOWFISH,
-			GCRY_CIPHER_MODE_ECB, 0);
-	gcry_cipher_setkey (ph->partner.in, (const unsigned char *) inkey,
-			strlen (inkey));
+	if (gcry_cipher_open (&ph->partner.in, GCRY_CIPHER_BLOWFISH,
+			GCRY_CIPHER_MODE_ECB, 0) != GPG_ERR_NO_ERROR) {
+		return PIANO_RET_GCRY_ERR;
+	}
+	if (gcry_cipher_setkey (ph->partner.in, (const unsigned char *) inkey,
+			strlen (inkey)) != GPG_ERR_NO_ERROR) {
+		return PIANO_RET_GCRY_ERR;
+	}
 
-	gcry_cipher_open (&ph->partner.out, GCRY_CIPHER_BLOWFISH,
-			GCRY_CIPHER_MODE_ECB, 0);
-	gcry_cipher_setkey (ph->partner.out, (const unsigned char *) outkey,
-			strlen (outkey));
+	if (gcry_cipher_open (&ph->partner.out, GCRY_CIPHER_BLOWFISH,
+			GCRY_CIPHER_MODE_ECB, 0) != GPG_ERR_NO_ERROR) {
+		return PIANO_RET_GCRY_ERR;
+	}
+	if (gcry_cipher_setkey (ph->partner.out, (const unsigned char *) outkey,
+			strlen (outkey)) != GPG_ERR_NO_ERROR) {
+		return PIANO_RET_GCRY_ERR;
+	}
+
+	return PIANO_RET_OK;
 }
 
 /*	destroy artist linked list
@@ -70,7 +80,7 @@ static void PianoDestroyArtists (PianoArtist_t *artists) {
 		free (curArtist->musicId);
 		free (curArtist->seedId);
 		lastArtist = curArtist;
-		curArtist = curArtist->next;
+		curArtist = (PianoArtist_t *) curArtist->head.next;
 		free (lastArtist);
 	}
 }
@@ -103,7 +113,7 @@ static void PianoDestroyStations (PianoStation_t *stations) {
 	curStation = stations;
 	while (curStation != NULL) {
 		lastStation = curStation;
-		curStation = curStation->next;
+		curStation = (PianoStation_t *) curStation->head.next;
 		PianoDestroyStation (lastStation);
 		free (lastStation);
 	}
@@ -131,7 +141,7 @@ void PianoDestroyPlaylist (PianoSong_t *playlist) {
 		free (curSong->detailUrl);
 		free (curSong->trackToken);
 		lastSong = curSong;
-		curSong = curSong->next;
+		curSong = (PianoSong_t *) curSong->head.next;
 		free (lastSong);
 	}
 }
@@ -153,7 +163,7 @@ static void PianoDestroyGenres (PianoGenre_t *genres) {
 		free (curGenre->name);
 		free (curGenre->musicId);
 		lastGenre = curGenre;
-		curGenre = curGenre->next;
+		curGenre = (PianoGenre_t *) curGenre->head.next;
 		free (lastGenre);
 	}
 }
@@ -191,7 +201,7 @@ void PianoDestroy (PianoHandle_t *ph) {
 		PianoDestroyGenres (curGenreCat->genres);
 		free (curGenreCat->name);
 		lastGenreCat = curGenreCat;
-		curGenreCat = curGenreCat->next;
+		curGenreCat = (PianoGenreCategory_t *) curGenreCat->head.next;
 		free (lastGenreCat);
 	}
 	memset (ph, 0, sizeof (*ph));
@@ -211,14 +221,17 @@ void PianoDestroyRequest (PianoRequest_t *req) {
  *	@param search for this
  *	@return the first station structure matching the given id
  */
-PianoStation_t *PianoFindStationById (PianoStation_t *stations,
-		const char *searchStation) {
-	while (stations != NULL) {
-		if (strcmp (stations->id, searchStation) == 0) {
-			return stations;
+PianoStation_t *PianoFindStationById (PianoStation_t * const stations,
+		const char * const searchStation) {
+	assert (searchStation != NULL);
+
+	PianoStation_t *currStation = stations;
+	PianoListForeachP (currStation) {
+		if (strcmp (currStation->id, searchStation) == 0) {
+			return currStation;
 		}
-		stations = stations->next;
 	}
+
 	return NULL;
 }
 
@@ -258,6 +271,10 @@ const char *PianoErrorToStr (PianoReturn_t ret) {
 			return "Selected audio quality is not available.";
 			break;
 
+		case PIANO_RET_GCRY_ERR:
+			return "libgcrypt initialization failed.";
+			break;
+
 		/* pandora error messages */
 		case PIANO_RET_P_INTERNAL:
 			return "Internal error.";
@@ -304,6 +321,10 @@ const char *PianoErrorToStr (PianoReturn_t ret) {
 			return "Listener not authorized.";
 			break;
 
+		case PIANO_RET_P_RATE_LIMIT:
+			return "Access denied. Try again later.";
+			break;
+
 		default:
 			return "No error message available.";
 			break;
