@@ -21,8 +21,8 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 */
 
-#ifndef _PIANO_H
-#define _PIANO_H
+#ifndef SRC_LIBPIANO_PIANO_H_MFBT13PN
+#define SRC_LIBPIANO_PIANO_H_MFBT13PN
 
 #include <stdbool.h>
 #ifdef __FreeBSD__
@@ -95,6 +95,7 @@ typedef struct PianoSong {
 	char *detailUrl;
 	char *trackToken;
 	float fileGain;
+	unsigned int length; /* song length in seconds */
 	PianoSongRating_t rating;
 	PianoAudioFormat_t audioFormat;
 } PianoSong_t;
@@ -310,14 +311,17 @@ size_t PianoListCount (const PianoListHead_t * const l);
 #define PianoListCountP(l) PianoListCount(&(l)->head)
 void *PianoListAppend (PianoListHead_t * const l, PianoListHead_t * const e)
 		__attribute__ ((warn_unused_result));
-#define PianoListAppendP(l,e) PianoListAppend(&(l)->head, &(e)->head)
+#define PianoListAppendP(l,e) PianoListAppend(((l) == NULL) ? NULL : &(l)->head, \
+		&(e)->head)
 void *PianoListDelete (PianoListHead_t * const l, PianoListHead_t * const e)
 		__attribute__ ((warn_unused_result));
-#define PianoListDeleteP(l,e) PianoListDelete(&(l)->head, &(e)->head)
+#define PianoListDeleteP(l,e) PianoListDelete(((l) == NULL) ? NULL : &(l)->head, \
+		&(e)->head)
 #define PianoListNextP(e) ((void *) (e)->head.next)
 void *PianoListPrepend (PianoListHead_t * const l, PianoListHead_t * const e)
 		__attribute__ ((warn_unused_result));
-#define PianoListPrependP(l,e) PianoListPrepend (&(l)->head, &(e)->head)
+#define PianoListPrependP(l,e) PianoListPrepend (((l) == NULL) ? NULL : &(l)->head, \
+		&(e)->head)
 void *PianoListGet (PianoListHead_t * const l, const size_t n);
 #define PianoListGetP(l,n) PianoListGet (&(l)->head, n)
 #define PianoListForeachP(l) for (; (l) != NULL; (l) = (void *) (l)->head.next)
@@ -342,4 +346,4 @@ PianoStation_t *PianoFindStationById (PianoStation_t * const,
 		const char * const);
 const char *PianoErrorToStr (PianoReturn_t);
 
-#endif /* _PIANO_H */
+#endif /* SRC_LIBPIANO_PIANO_H_MFBT13PN */
