@@ -807,11 +807,6 @@ static WaitressReturn_t WaitressConnect (WaitressHandle_t *waith) {
 			/* we need shorter timeouts for connect() */
 			fcntl (sock, F_SETFL, O_NONBLOCK);
 
-			/* increase socket receive buffer */
-			const int sockopt = 256*1024;
-			setsockopt (sock, SOL_SOCKET, SO_RCVBUF, &sockopt,
-					sizeof (sockopt));
-
 			/* non-blocking connect will return immediately */
 			connect (sock, gacurr->ai_addr, gacurr->ai_addrlen);
 
@@ -873,6 +868,10 @@ static WaitressReturn_t WaitressConnect (WaitressHandle_t *waith) {
 			}
 		}
 
+		/* Ignore return code as connection will likely still succeed */
+		gnutls_server_name_set (waith->request.tlsSession, GNUTLS_NAME_DNS,
+				waith->url.host, strlen (waith->url.host));
+
 		if (gnutls_handshake (waith->request.tlsSession) != GNUTLS_E_SUCCESS) {
 			return WAITRESS_RET_TLS_HANDSHAKE_ERR;
 		}
@@ -910,21 +909,18 @@ static WaitressReturn_t WaitressSendRequest (WaitressHandle_t *waith) {
 	/* send request */
 	if (WaitressProxyEnabled (waith) && !waith->url.tls) {
 		snprintf (buf, WAITRESS_BUFFER_SIZE,
-			"%s http://%s:%s/%s HTTP/" WAITRESS_HTTP_VERSION "\r\n",
+			"%s http://%s:%s/%s HTTP/" WAITRESS_HTTP_VERSION "\r\n"
+			"Host: %s\r\nUser-Agent: " PACKAGE "\r\nConnection: Close\r\n",
 			(waith->method == WAITRESS_METHOD_GET ? "GET" : "POST"),
 			waith->url.host,
-			WaitressDefaultPort (&waith->url), path);
+			WaitressDefaultPort (&waith->url), path, waith->url.host);
 	} else {
 		snprintf (buf, WAITRESS_BUFFER_SIZE,
-			"%s /%s HTTP/" WAITRESS_HTTP_VERSION "\r\n",
-			(waith->method == WAITRESS_METHOD_GET ? "GET" : "POST"),
-			path);
-	}
-	WRITE_RET (buf, strlen (buf));
-
-	snprintf (buf, WAITRESS_BUFFER_SIZE,
+			"%s /%s HTTP/" WAITRESS_HTTP_VERSION "\r\n"
 			"Host: %s\r\nUser-Agent: " PACKAGE "\r\nConnection: Close\r\n",
-			waith->url.host);
+			(waith->method == WAITRESS_METHOD_GET ? "GET" : "POST"),
+			path, waith->url.host);
+	}
 	WRITE_RET (buf, strlen (buf));
 
 	if (waith->method == WAITRESS_METHOD_POST && waith->postData != NULL) {
@@ -1193,7 +1189,7 @@ const char *WaitressErrorToStr (WaitressReturn_t wRet) {
 			break;
 
 		case WAITRESS_RET_GETADDR_ERR:
-			return "getaddr failed.";
+			return "DNS lookup failed.";
 			break;
 
 		case WAITRESS_RET_CB_ABORT:
