@@ -51,7 +51,6 @@ THE SOFTWARE.
 #include <sys/types.h>
 #include <sys/wait.h>
 
-
 /* pandora.com library */
 #include <piano.h>
 
@@ -70,9 +69,17 @@ static void BarMainLoadProxy (const BarSettings_t *settings,
 	 * firewalled fellows) */
 	if (settings->controlProxy != NULL) {
 		/* control proxy overrides global proxy */
-		WaitressSetProxy (waith, settings->controlProxy);
+		if (!WaitressSetProxy (waith, settings->controlProxy)) {
+			/* if setting proxy fails, url is invalid */
+			BarUiMsg (settings, MSG_ERR, "Control proxy (%s) is invalid!\n",
+					 settings->controlProxy);
+		}
 	} else if (settings->proxy != NULL && strlen (settings->proxy) > 0) {
-		WaitressSetProxy (waith, settings->proxy);
+		if (!WaitressSetProxy (waith, settings->proxy)) {
+			/* if setting proxy fails, url is invalid */
+			BarUiMsg (settings, MSG_ERR, "Proxy (%s) is invalid!\n",
+					 settings->proxy);
+		}
 	}
 }
 
@@ -99,17 +106,24 @@ static bool BarMainLoginUser (BarApp_t *app) {
  */
 static bool BarMainGetLoginCredentials (BarSettings_t *settings,
 		BarReadlineFds_t *input) {
+	bool usernameFromConfig = true;
+
 	if (settings->username == NULL) {
 		char nameBuf[100];
 
 		BarUiMsg (settings, MSG_QUESTION, "Email: ");
 		BarReadlineStr (nameBuf, sizeof (nameBuf), input, BAR_RL_DEFAULT);
 		settings->username = strdup (nameBuf);
+		usernameFromConfig = false;
 	}
 
 	if (settings->password == NULL) {
 		char passBuf[100];
 
+		if (usernameFromConfig) {
+			BarUiMsg (settings, MSG_QUESTION, "Email: %s\n", settings->username);
+		}
+
 		if (settings->passwordCmd == NULL) {
 			BarUiMsg (settings, MSG_QUESTION, "Password: ");
 			BarReadlineStr (passBuf, sizeof (passBuf), input, BAR_RL_NOECHO);
@@ -164,8 +178,7 @@ static bool BarMainGetLoginCredentials (BarSettings_t *settings,
 					return false;
 				}
 			}
-
-		}
+		} /* end else passwordCmd */
 	}
 
 	return true;
@@ -246,37 +259,38 @@ static void BarMainGetPlaylist (BarApp_t *app) {
 /*	start new player thread
  */
 static void BarMainStartPlayback (BarApp_t *app, pthread_t *playerThread) {
-	BarUiPrintSong (&app->settings, app->playlist, app->curStation->isQuickMix ?
-			PianoFindStationById (app->ph.stations,
-			app->playlist->stationId) : NULL);
+	assert (app != NULL);
+	assert (playerThread != NULL);
 
-	if (app->playlist->audioUrl == NULL) {
+	const PianoSong_t * const curSong = app->playlist;
+	assert (curSong != NULL);
+
+	BarUiPrintSong (&app->settings, curSong, app->curStation->isQuickMix ?
+			PianoFindStationById (app->ph.stations,
+			curSong->stationId) : NULL);
+
+	static const char httpPrefix[] = "http://";
+	/* avoid playing local files */
+	if (curSong->audioUrl == NULL ||
+			strncmp (curSong->audioUrl, httpPrefix, strlen (httpPrefix)) != 0) {
 		BarUiMsg (&app->settings, MSG_ERR, "Invalid song url.\n");
 	} else {
 		/* setup player */
 		memset (&app->player, 0, sizeof (app->player));
 
-		WaitressInit (&app->player.waith);
-		WaitressSetUrl (&app->player.waith, app->playlist->audioUrl);
-
-		/* set up global proxy, player is NULLed on songfinish */
-		if (app->settings.proxy != NULL) {
-			WaitressSetProxy (&app->player.waith, app->settings.proxy);
-		}
-
-		app->player.gain = app->playlist->fileGain;
-		app->player.scale = BarPlayerCalcScale (app->player.gain + app->settings.volume);
-		app->player.audioFormat = app->playlist->audioFormat;
+		app->player.url = curSong->audioUrl;
+		app->player.gain = curSong->fileGain;
 		app->player.settings = &app->settings;
+		app->player.songDuration = curSong->length;
 		pthread_mutex_init (&app->player.pauseMutex, NULL);
 		pthread_cond_init (&app->player.pauseCond, NULL);
 
 		/* throw event */
 		BarUiStartEventCmd (&app->settings, "songstart",
-				app->curStation, app->playlist, &app->player, app->ph.stations,
+				app->curStation, curSong, &app->player, app->ph.stations,
 				PIANO_RET_OK, WAITRESS_RET_OK);
 
-		/* prevent race condition, mode must _not_ be FREED if
+		/* prevent race condition, mode must _not_ be DEAD if
 		 * thread has been started */
 		app->player.mode = PLAYER_STARTING;
 		/* start player */
@@ -318,21 +332,21 @@ static void BarMainPlayerCleanup (BarApp_t *app, pthread_t *playerThread) {
 /*	print song duration
  */
 static void BarMainPrintTime (BarApp_t *app) {
-	/* Ugly: songDuration is unsigned _long_ int! Lets hope this won't
-	 * overflow */
-	int songRemaining = (signed long int) (app->player.songDuration -
-			app->player.songPlayed) / BAR_PLAYER_MS_TO_S_FACTOR;
-	enum {POSITIVE, NEGATIVE} sign = NEGATIVE;
-	if (songRemaining < 0) {
-		/* song is longer than expected */
-		sign = POSITIVE;
-		songRemaining = -songRemaining;
+	unsigned int songRemaining;
+	char sign;
+
+	if (app->player.songPlayed <= app->player.songDuration) {
+		songRemaining = app->player.songDuration - app->player.songPlayed;
+		sign = '-';
+	} else {
+		/* longer than expected */
+		songRemaining = app->player.songPlayed - app->player.songDuration;
+		sign = '+';
 	}
-	BarUiMsg (&app->settings, MSG_TIME, "%c%02i:%02i/%02i:%02i\r",
-			(sign == POSITIVE ? '+' : '-'),
-			songRemaining / 60, songRemaining % 60,
-			app->player.songDuration / BAR_PLAYER_MS_TO_S_FACTOR / 60,
-			app->player.songDuration / BAR_PLAYER_MS_TO_S_FACTOR % 60);
+	BarUiMsg (&app->settings, MSG_TIME, "%c%02u:%02u/%02u:%02u\r",
+			sign, songRemaining / 60, songRemaining % 60,
+			app->player.songDuration / 60,
+			app->player.songDuration % 60);
 }
 
 /*	main loop
@@ -362,13 +376,13 @@ static void BarMainLoop (BarApp_t *app) {
 
 	while (!app->doQuit) {
 		/* song finished playing, clean up things/scrobble song */
-		if (app->player.mode == PLAYER_FINISHED_PLAYBACK) {
+		if (app->player.mode == PLAYER_FINISHED) {
 			BarMainPlayerCleanup (app, &playerThread);
 		}
 
 		/* check whether player finished playing and start playing new
 		 * song */
-		if (app->player.mode == PLAYER_FREED && app->curStation != NULL) {
+		if (app->player.mode == PLAYER_DEAD && app->curStation != NULL) {
 			/* what's next? */
 			if (app->playlist != NULL) {
 				PianoSong_t *histsong = app->playlist;
@@ -388,13 +402,12 @@ static void BarMainLoop (BarApp_t *app) {
 		BarMainHandleUserInput (app);
 
 		/* show time */
-		if (app->player.mode >= PLAYER_SAMPLESIZE_INITIALIZED &&
-				app->player.mode < PLAYER_FINISHED_PLAYBACK) {
+		if (app->player.mode == PLAYER_PLAYING) {
 			BarMainPrintTime (app);
 		}
 	}
 
-	if (app->player.mode != PLAYER_FREED) {
+	if (app->player.mode != PLAYER_DEAD) {
 		pthread_join (playerThread, NULL);
 	}
 }
@@ -415,11 +428,11 @@ int main (int argc, char **argv) {
 	signal (SIGPIPE, SIG_IGN);
 
 	/* init some things */
-	ao_initialize ();
 	gcry_check_version (NULL);
 	gcry_control (GCRYCTL_DISABLE_SECMEM, 0);
 	gcry_control (GCRYCTL_INITIALIZATION_FINISHED, 0);
 	gnutls_global_init ();
+	BarPlayerInit ();
 
 	BarSettingsInit (&app.settings);
 	BarSettingsRead (&app.settings);
@@ -488,7 +501,7 @@ int main (int argc, char **argv) {
 	PianoDestroyPlaylist (app.songHistory);
 	PianoDestroyPlaylist (app.playlist);
 	WaitressFree (&app.waith);
-	ao_shutdown();
+	BarPlayerDestroy ();
 	gnutls_global_deinit ();
 	BarSettingsDestroy (&app.settings);
 
