@@ -21,8 +21,8 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 */
 
-#ifndef _UI_H
-#define _UI_H
+#ifndef SRC_UI_H_46P20TS0
+#define SRC_UI_H_46P20TS0
 
 #include <stdbool.h>
 
@@ -37,7 +37,7 @@ THE SOFTWARE.
 
 typedef void (*BarUiSelectStationCallback_t) (BarApp_t *app, char *buf);
 
-void BarUiMsg (const BarSettings_t *, const BarUiMsg_t, const char *, ...);
+void BarUiMsg (const BarSettings_t *, const BarUiMsg_t, const char *, ...) __attribute__((format(printf, 3, 4)));
 PianoStation_t *BarUiSelectStation (BarApp_t *, PianoStation_t *, const char *,
 		BarUiSelectStationCallback_t, bool);
 PianoSong_t *BarUiSelectSong (const BarSettings_t *, PianoSong_t *,
@@ -55,4 +55,4 @@ int BarUiPianoCall (BarApp_t * const, PianoRequestType_t,
 		void *, PianoReturn_t *, WaitressReturn_t *);
 void BarUiHistoryPrepend (BarApp_t *app, PianoSong_t *song);
 
-#endif /* _UI_H */
+#endif /* SRC_UI_H_46P20TS0 */
